@@ -19,9 +19,9 @@ from lxml import etree
 import warnings
 import copy
 import logging
-from typing import cast
+from typing import cast, Any
 
-from .xpathbuilder import XPathBuilder
+from .xpathbuilder import FilterType, XPathBuilder
 
 
 def clear_xml(tree: etree._ElementTree) -> tuple[etree._ElementTree, set[str]]:
@@ -461,3 +461,46 @@ def is_valid_tag(tag: str) -> bool:
         return True
     except ValueError:
         return False
+
+
+def serialize_xml_objects(args: tuple[Any, ...], kwargs: dict[str, Any]) -> tuple[tuple[Any, ...], dict[str, Any]]:
+    """
+    Convert every XML element/tree in the given args/kwargs to string
+    using :py:func:`lxml.etree.tostring()`
+
+    :param args: positional arguments
+    :param kwargs: keyword arguments
+    """
+
+    def tostring(elem: XMLLike) -> str:
+        return etree.tostring(elem, encoding='unicode', pretty_print=True)
+
+    args = tuple(tostring(x) if isinstance(x, (etree._Element, etree._ElementTree)) else x for x in args)
+    kwargs = {k: tostring(x) if isinstance(x, (etree._Element, etree._ElementTree)) else x for k, x in kwargs.items()}
+
+    return args, kwargs
+
+
+def process_xpath_argument(simple_xpath: str | bytes | etree.XPath, complex_xpath: XPathLike | None,
+                           filters: FilterType | None) -> XPathLike:
+    """
+    Process the simple and complex Xpath expressions and given filters
+    Used for unifying the logic for all xml setters/evaluators using these arguments
+
+    :param simple_xpath: THe simple XPath (no predicates) expression to base the paths on
+    :param complex_xpath: Optional XPath given with no restrictions
+    :param filters: Dict specifying constraints to apply on the xpath.
+                    See :py:class:`~masci_tools.util.xml.xpathbuilder.XPathBuilder` for details
+
+    :returns: Complex XPath expression
+    """
+    if complex_xpath is None:
+        complex_xpath = XPathBuilder(simple_xpath, filters=filters, strict=True)
+    elif filters is not None:
+        if not isinstance(complex_xpath, XPathBuilder):
+            raise ValueError(
+                'Provide only one of filters or complex_xpath (Except when complx_xpath is given as a XPathBuilder)')
+        for key, val in filters.items():
+            complex_xpath.add_filter(key, val)
+
+    return complex_xpath
